@@ -1,7 +1,7 @@
 from django import forms
 from django.contrib.contenttypes.models import ContentType
 
-from simple_import.models import ImportLog, ColumnMatch
+from simple_import.models import ImportLog, ColumnMatch, RelationalMatch
 
 
 class ImportForm(forms.ModelForm):
@@ -13,4 +13,11 @@ class ImportForm(forms.ModelForm):
     
 class MatchForm(forms.ModelForm):
     class Meta:
-        model = ColumnMatch
\ No newline at end of file
+        model = ColumnMatch
+
+class MatchRelationForm(forms.ModelForm):
+    class Meta:
+        model = RelationalMatch
+        widgets = {
+            'related_field_name': forms.Select(choices=(('', '---------'),))
+        }
